#EXPREPORT

## cli example

### word format
expreport --data=/pathofdata/data/2.csv --out=/pathofgenerateddata/data/generate

### excel format
expreport --data=/pathofdata/data/1.csv --out=/pathofdata/data/generate/file.xlsx --excel=True


